@@ -69,6 +69,7 @@ class FunkLoadTestCase(unittest.TestCase):
         unittest.TestCase.__init__(self, methodName=self.test_name)
         self._response = None
         self.options = options
+        self.debug_level = getattr(options, 'debug_level', 0)
         self._funkload_init()
         self._dump_dir = getattr(options, 'dump_dir', None)
         self._dumping =  self._dump_dir and True or False
@@ -105,6 +106,9 @@ class FunkLoadTestCase(unittest.TestCase):
         config.read(config_path)
         self._config = config
         self._config_path = config_path
+        self.default_user_agent = self.conf_get('main', 'user_agent',
+                                                'FunkLoad/%s' % get_version(),
+                                                quiet=True)
         if self.in_bench_mode:
             section = 'bench'
         else:
@@ -131,9 +135,7 @@ class FunkLoadTestCase(unittest.TestCase):
         # init webunit browser (passing a fake methodName)
         self._browser = WebTestCase(methodName='log')
         self.clearContext()
-        self.setUserAgent(self.conf_get('main', 'user_agent',
-                                        'FunkLoad/%s' % get_version(),
-                                        quiet=True))
+        
         #self.logd('# FunkLoadTestCase._funkload_init done')
 
     def clearContext(self):
@@ -153,7 +155,9 @@ class FunkLoadTestCase(unittest.TestCase):
         self.total_xmlrpc = 0
         self.clearBasicAuth()
         self.clearHeaders()
-        #self.logd('# FunkLoadTestCase.clearContext done')
+        self.setUserAgent(self.default_user_agent)
+
+        self.logdd('FunkLoadTestCase.clearContext done')
 
 
 
@@ -578,6 +582,11 @@ class FunkLoadTestCase(unittest.TestCase):
         """Debug log."""
         self.logger.debug(self.meta_method_name +': ' +message)
 
+    def logdd(self, message):
+        """Verbose Debug log."""
+        if self.debug_level >= 2:
+            self.logger.debug(self.meta_method_name +': ' +message)
+
     def logi(self, message):
         """Info log."""
         if hasattr(self, 'logger'):
@@ -729,8 +738,15 @@ class FunkLoadTestCase(unittest.TestCase):
             return
         if not os.access(dump_dir, os.W_OK):
             os.mkdir(dump_dir, 0775)
+        content_type = response.headers.get('content-type')
+        if content_type == 'text/xml':
+            ext = '.xml'
+        else:
+            ext = os.path.splitext(response.url)[1]
+            if not ext.startswith('.') or len(ext) > 4:
+                ext = '.html'
         file_path = os.path.abspath(
-            os.path.join(dump_dir, '%3.3i.html' % self.steps))
+            os.path.join(dump_dir, '%3.3i%s' % (self.steps, ext)))
         f = open(file_path, 'w')
         f.write(response.body)
         f.close()
