@@ -15,14 +15,15 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 # 02111-1307, USA.
 #
-"""Simple FunkLoad Test Recorder.
+"""TCPWatch FunkLoad Test Recorder.
+
+Requires tcpwatch.py available at:
 
-require tcpwatch.py
 * http://hathawaymix.org/Software/TCPWatch/tcpwatch-1.3.tar.gz
 
 Credits goes to Ian Bicking for parsing tcpwatch files.
 
-$Id: Recorder.py 29359 2005-11-08 20:55:33Z bdelbosc $
+$Id: Recorder.py 30292 2005-12-05 15:48:35Z bdelbosc $
 """
 import os
 import sys
@@ -220,7 +221,7 @@ Examples
             name = name[len(self.prefix):]
             ext = ext[1:]
             if ext == 'errors':
-                trace("Error in response %s" % name)
+                trace("Error in response %s\n" % name)
                 continue
             assert ext in ('request', 'response'), "Bad extension: %r" % ext
             items.setdefault(name, {})[ext] = os.path.join(
@@ -289,7 +290,7 @@ Examples
                 for request in requests]
         if not code:
             trace("Sorry no action recorded.\n")
-            return
+            return ''
         code.insert(0, '')
         return self.reindent('\n'.join(code))
 
